# PySubCMedians

__Authors__: Sergio Peignier, Christophe Rigotti, Anthony Rossi and Guillaume Beslon

Python implementation of the SubCMedians algorithm. SubCMedians is a Subspace Clustering algorithm that extends the K-medians paradigm. SubCMedians is a simple hill climbing algorithm based on stochastic weighted local exploration steps. This median based algorithm exhibits satisfactory quality clusters when compared to well-established paradigms, while medians have still their own interests depending on the user application (robustness to noise/outliers and location optimality). Detailled description available in the paper "Weight-based search to find clusters around medians in subspaces" presented in the ACM SAC conference 2018.

# Installation



# Dependencies :

+ numpy
+ pandas
+ seaborn
+ scikit-learn
+ scipy
+ tqdm
